import { AssetEnvelope } from "./mixer/AssetEnvelope";
import { TrackOptions } from "./mixer/TrackOptions";
import { PlaylistAudiotrack } from "./playlistAudioTrack";
import { IMixParams } from "./types";
import { IDecoratedAsset } from "./types/asset";
import { ICommonStateProperties } from "./types/track-states";
/**
 Common sequence of states:
                          (if asset not available)
              =>   =>   Loading     =>  WaitingForAsset (returns to Loading after 10s)
              ↑             ↓ (asset found)
              ↑         FadingIn
              ↑             ↓
              ↑         PlayingState
              ↑             ↓
              ↑         FadingOutState
              ↑             ↓
              <=   <=   DeadAirState
                        
                        
         => WaitingForAssetState
 */
/**
 * When Asset not loaded
 * @implements {ICommonStateProperties}
 */
export declare class LoadingState implements ICommonStateProperties {
    track: PlaylistAudiotrack;
    trackOptions: TrackOptions;
    asset: IDecoratedAsset | null;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions);
    /**
     * This will load next assets to play, and transiton to FadingInState or WaitingForAssetState if not asset if loaded
     */
    play(): void;
    pause(): void;
    finish(): void;
    skip(): void;
    replay(): void;
    updateParams(): void;
    toString(): string;
}
/**
 *
 *When asset is available
 */
export declare class TimedTrackState implements ICommonStateProperties {
    track: PlaylistAudiotrack;
    windowScope: Window;
    trackOptions: TrackOptions;
    timerId: null | number;
    intervalId: null | number;
    timeRemainingMs?: number;
    timerApproximateEndingAtMs?: number;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions);
    /**
     * This will set a timer for next state
     * @param  {number=0} nextStateSecs
     * @returns number - seconds for nextState can be approximately called
     */
    play(nextStateSecs?: number): number | void;
    /**
     */
    pause(): void;
    clearTimer(): number;
    finish(): void;
    setNextStateTimer(timeMs: number): void;
    log(string: string): void;
    setNextState(): void;
    skip(): void;
    replay(): void;
    setLoadingState(): void;
    updateParams(params: IMixParams): void;
}
/**
 *Plays silence and jumps to LoadingState
 */
export declare class DeadAirState extends TimedTrackState implements ICommonStateProperties {
    deadAirSeconds: number;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions);
    play(): void;
    setNextState(): void;
    toString(): string;
}
export declare class FadingInState extends TimedTrackState implements ICommonStateProperties {
    assetEnvelope: AssetEnvelope;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions, { assetEnvelope }: {
        assetEnvelope: AssetEnvelope;
    });
    /**
     * Will fadeIn
     * @memberof FadingInState
     */
    play(): void;
    pause(): void;
    setNextState(): void;
    toString(): string;
    replay(): void;
    updateParams(mixParams: IMixParams): void;
}
export declare class PlayingState extends TimedTrackState implements ICommonStateProperties {
    assetEnvelope: AssetEnvelope;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions, { assetEnvelope }: {
        assetEnvelope: AssetEnvelope;
    });
    play(): void;
    pause(): void;
    toString(): string;
    setNextState(): void;
    updateParams(mixParams: IMixParams): void;
}
export declare class FadingOutState extends TimedTrackState implements ICommonStateProperties {
    assetEnvelope: AssetEnvelope;
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions, { assetEnvelope }: {
        assetEnvelope: AssetEnvelope;
    });
    play(): void;
    pause(): void;
    setNextState(): void;
    finish(): void;
    toString(): string;
    updateParams(mixParams: IMixParams): void;
}
/**
 *
 * State when nextAsset is becoming `null`
 * Will wait for 10 seconds and move to LoadingState to check new assets can be loaded
 * Also if location is updated will automatically move to LoadingState
 * @implements {ICommonStateProperties}
 */
export declare class WaitingForAssetState extends TimedTrackState implements ICommonStateProperties {
    constructor(track: PlaylistAudiotrack, trackOptions: TrackOptions);
    play(): void;
    updateParams(params?: {}): void;
    setNextState(): void;
    toString(): string;
}
export declare const makeInitialTrackState: (track: PlaylistAudiotrack, trackOptions: TrackOptions) => LoadingState | DeadAirState;
