import { ApiClient } from "./api-client";
import { AssetPool } from "./assetPool";
import { Envelope } from "./envelope";
import { RoundwareEvents } from "./events";
import { GeoPosition } from "./geo-position";
import { Mixer } from "./mixer";
import { Project } from "./project";
import { Coordinates, GeoListenModeType, IAudioData, IMixParams, ITimedAssetData, IUiConfig } from "./types";
import { IAssetFilters } from "./types/asset";
import { IAssetData } from "./types/asset";
import { IAudioTrackData } from "./types/audioTrack";
import { IEnvelopeData } from "./types/envelope";
import { IRoundwareConstructorOptions } from "./types/roundware";
import { ISpeakerData } from "./types/speaker";
import { User } from "./user";
export * from "./assetFilters";
export { GeoListenMode } from "./mixer";
import { ListenHistory } from "./listenHistory";
/** This class is the primary integration point between Roundware's server and your application

   @example
   var roundwareServerUrl = "http://localhost:8888/api/2";
   var roundwareProjectId = 1;

   var roundware = new Roundware(window,{
     serverUrl: roundwareServerUrl,
     projectId: roundwareProjectId
   });

   function ready() {
     console.info("Connected to Roundware Server. Ready to play.");
     // this is a good place to initialize audio player controls, etc.
   }

   // Generally we throw user-friendly messages and log a more technical message
   function handleError(userErrMsg) {
     console.error("Roundware Error: " + userErrMsg);
   }

  roundware.connect().
    then(ready).
    catch(handleError);

  function startListening(streamURL) {
    console.info("Loading " + streamURL);
    // good place to connect your audio player to the audio stream
  }

  roundware.play(startListening).catch(handleError);
**/
export declare class Roundware {
    readonly windowScope: Window;
    private _serverUrl;
    private _projectId;
    private _speakerFilters;
    private _assetFilters;
    listenerLocation: Coordinates;
    private _initialOptions;
    private _assetUpdateInterval;
    apiClient: ApiClient;
    user: User;
    geoPosition: GeoPosition;
    private _session;
    project: Project;
    private _speaker;
    private _asset;
    private _timed_asset;
    private _audiotrack;
    mixer: Mixer;
    private _onUpdateLocation;
    private _onUpdateAssets;
    assetData: IAssetData[] | null;
    private _onPlayAssets;
    private _sessionId;
    uiConfig: IUiConfig;
    private _speakerData;
    private _audioTracksData;
    private _lastAssetUpdate;
    timedAssetData: ITimedAssetData[] | null;
    private _assetDataTimer;
    listenHistory: ListenHistory;
    events?: RoundwareEvents;
    /** Initialize a new Roundware instance
     * @param {Object} windowScope - representing the context in which we are executing - provides references to window.navigator, window.console, etc.
     * @param {Object} options - Collection of parameters for configuring this Roundware instance
     * @param {String} options.serverUrl - identifies the Roundware server
     * @param {Number} options.projectId - identifies the Roundware project to connect
     * @param {number} options.geoListenMode - whether or not to attempt to initialize geolocation-based listening
     * @throws Will throw an error if serveUrl or projectId are missing
      TODO need to provide a more modern/ES6-aware architecture here vs burdening the constructor with all of these details **/
    constructor(windowScope: Window, options: IRoundwareConstructorOptions);
    updateLocation(listenerLocation: Coordinates): void;
    set onUpdateLocation(callback: (lastCoords: Coordinates) => any);
    set onUpdateAssets(callback: (assets?: IAssetData[]) => any);
    set onPlayAssets(callback: (currentlyPlaylingAssets?: IAssetData[]) => any);
    triggerOnPlayAssets(): void;
    get currentlyPlayingAssets(): IAssetData[] | undefined;
    enableGeolocation(mode: GeoListenModeType): void;
    disableGeolocation(): void;
    /** Initiate a connection to Roundware
     *  @return {Promise} - Can be resolved in order to get the audio stream URL, or rejected to get an error message; see example above **/
    connect(): Promise<{
        uiConfig: IUiConfig;
    }>;
    get mixParams(): {};
    getAssets(options?: IAssetFilters): Promise<IAssetData[]>;
    get assetPool(): AssetPool | undefined;
    getAssetsFromPool(assetFilter: (asset: IAssetData, mixParams: IMixParams) => boolean, extraParams?: IMixParams): Promise<IAssetData[]>;
    updateAssetPool(): Promise<void>;
    loadAssetPool(): Promise<IAssetData[]>;
    /**
     * Updates params with passed params, Builds playlist instance, loads assetPool
     * @param  {IMixParams} activationParams
     * @returns Mixer
     */
    activateMixer(activationParams?: IMixParams): Promise<Mixer>;
    /** Create or resume the audio stream
     * @see Mixer.toogle **/
    play(firstPlayCallback?: (value: Coordinates) => any): Promise<any>;
    /** Tell Roundware server to pause the audio stream. You should always call this when the local audio player has been paused.
     * @see Mixer.playlist.pause **/
    pause(): void;
    /** Tell Roundware server to kill the audio stream.
     * @see Stream.kill **/
    kill(): void;
    /** Tell Roundware server to replay the current asset.
     * @see Stream.replay **/
    replay(): void;
    /** Tell Roundware server to skip the current asset.
     * @see Stream.skip **/
    skip(): void;
    /** Update the Roundware stream with new tag IDs
     * @param {string} tagIdStr - comma-separated list of tag IDs to send to the streams API **/
    tags(): void;
    /** Update the Roundware stream with new tag IDs and or geo-position
     * @param {object} data - containing keys latitude, longitude and tagIds **/
    update(data: {
        latitude: number;
        longitude: number;
        tagIds: string[] | number[];
    }): void;
    speakers(): ISpeakerData[];
    assets(): IAssetData[];
    timedAssets(): ITimedAssetData[] | [];
    audiotracks(): IAudioTrackData[] | [];
    /** Attach new assets to the project
     * @param {Object} audioData - the binary data from a recording to be saved as an asset
     * @param {string} fileName - name of the file
     * @return {promise} - represents the API calls to save an asset; can be tested to find out whether upload was successful
     * @see Envelope.upload */
    saveAsset(audioData: IAudioData, fileName: string, data: object): Promise<{
        detail: string;
        envelope_ids: number[];
    }>;
    /** Explicitly make a new envelope that you can attach multiple assets to by
     calling the `Envelope.upload` method. This is the main way to add text,
     photo, and video assets to an envelope. */
    makeEnvelope(): Promise<Envelope>;
    findTagDescription(tagId: number, tagType?: string): string | undefined;
    vote(assetId: number, voteType: string, value?: unknown): Promise<void>;
    getAsset(id: number): Promise<IAssetData>;
    getEnvelope(id: number): Promise<IEnvelopeData>;
    /**
     *
     * Calculates bounds for the map based on Speakers
     * @memberof Roundware
     */
    getMapBounds(): {
        southwest: Coordinates;
        northeast: Coordinates;
    };
}
